@@ -4,24 +4,14 @@ import sys
 
 modules = [
     "gtkhtml2",
-    "gnomeapplet",
-    "gnomeprint",
-    ("gnomeprint.ui", "gnomeprint"),
-    "gtksourceview",
     ("egg.trayicon", "egg/tray"),
     ("egg.recent", "egg/recent"),
-    "wnck",
     "gtkmozembed",
     "gtkspell",
     "gdl",
-    ("totem.plparser", "totem"),
-    "gtop",
-    "nautilusburn",
     "gda",
     "gksu",
     ("gksu.ui", "gksu"),
-    "mediaprofiles",
-    "metacity",
     ]
 
 import ltihooks
@@ -33,12 +23,15 @@ for item in modules:
         module = item
         dirname = item
     sys.path.insert(0, os.path.join("..", dirname))
+    print "Trying to import module %s... " % (module,),
     try:
         __import__(module) # try to import the module to catch undefined symbols
     except ImportError, ex:
         if ex.args[0].startswith("No module named"):
-            pass
+            print "not found"
         else:
             raise
+    else:
+        print "ok."
 
 ltihooks.uninstall()
